@@ -6,13 +6,20 @@ Numeric and string output labels are both handled.
 from copy import deepcopy
 
 import numpy as np
-import ray
+from joblib import Parallel, delayed
 from sklearn.base import BaseEstimator
 from sklearn.utils.validation import check_array, check_is_fitted
 
 from hiclass.ConstantClassifier import ConstantClassifier
 from hiclass.HierarchicalClassifier import HierarchicalClassifier
 
+try:
+    import ray
+except ImportError:
+    _has_ray = False
+else:
+    _has_ray = True
+
 
 class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
     """
@@ -40,6 +47,7 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
         edge_list: str = None,
         replace_classifiers: bool = True,
         n_jobs: int = 1,
+        bert: bool = False,
     ):
         """
         Initialize a local classifier per level.
@@ -60,6 +68,9 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
             a single unique class.
         n_jobs : int, default=1
             The number of jobs to run in parallel. Only :code:`fit` is parallelized.
+            If :code:`Ray` is installed it is used, otherwise it defaults to :code:`Joblib`.
+        bert : bool, default=False
+            If True, skip scikit-learn's checks and sample_weight passing for BERT.
         """
         super().__init__(
             local_classifier=local_classifier,
@@ -68,9 +79,10 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
             replace_classifiers=replace_classifiers,
             n_jobs=n_jobs,
             classifier_abbreviation="LCPL",
+            bert=bert,
         )
 
-    def fit(self, X, y):
+    def fit(self, X, y, sample_weight=None):
         """
         Fit a local classifier per level.
 
@@ -82,6 +94,9 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
             converted into a sparse ``csc_matrix``.
         y : array-like of shape (n_samples, n_levels)
             The target values, i.e., hierarchical class labels for classification.
+        sample_weight : array-like of shape (n_samples,), default=None
+            Array of weights that are assigned to individual samples.
+            If not provided, then each sample is given unit weight.
 
         Returns
         -------
@@ -89,7 +104,7 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
             Fitted estimator.
         """
         # Execute common methods necessary before fitting
-        super()._pre_fit(X, y)
+        super()._pre_fit(X, y, sample_weight)
 
         # Fit local classifiers in DAG
         super().fit(X, y)
@@ -124,7 +139,10 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
         check_is_fitted(self)
 
         # Input validation
-        X = check_array(X, accept_sparse="csr")
+        if not self.bert:
+            X = check_array(X, accept_sparse="csr")
+        else:
+            X = np.array(X)
 
         # Initialize array that holds predictions
         y = np.empty((X.shape[0], self.max_levels_), dtype=self.dtype_)
@@ -191,19 +209,27 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
         ]
         self.masks_ = [None for _ in range(self.y_.shape[1])]
 
-    def _fit_digraph(self, local_mode: bool = False):
+    def _fit_digraph(self, local_mode: bool = False, use_joblib: bool = False):
         self.logger_.info("Fitting local classifiers")
         if self.n_jobs > 1:
-            ray.init(
-                num_cpus=self.n_jobs, local_mode=local_mode, ignore_reinit_error=True
-            )
-            lcpl = ray.put(self)
-            _parallel_fit = ray.remote(self._fit_classifier)
-            results = [
-                _parallel_fit.remote(lcpl, level, self.separator_)
-                for level in range(len(self.local_classifiers_))
-            ]
-            classifiers = ray.get(results)
+            if _has_ray and not use_joblib:
+                ray.init(
+                    num_cpus=self.n_jobs,
+                    local_mode=local_mode,
+                    ignore_reinit_error=True,
+                )
+                lcpl = ray.put(self)
+                _parallel_fit = ray.remote(self._fit_classifier)
+                results = [
+                    _parallel_fit.remote(lcpl, level, self.separator_)
+                    for level in range(len(self.local_classifiers_))
+                ]
+                classifiers = ray.get(results)
+            else:
+                classifiers = Parallel(n_jobs=self.n_jobs)(
+                    delayed(self._fit_classifier)(self, level, self.separator_)
+                    for level in range(len(self.local_classifiers_))
+                )
         else:
             classifiers = [
                 self._fit_classifier(self, level, self.separator_)
@@ -216,17 +242,25 @@ class LocalClassifierPerLevel(BaseEstimator, HierarchicalClassifier):
     def _fit_classifier(self, level, separator):
         classifier = self.local_classifiers_[level]
 
-        X, y = self._remove_empty_leaves(separator, self.X_, self.y_[:, level])
+        X, y, sample_weight = self._remove_empty_leaves(
+            separator, self.X_, self.y_[:, level], self.sample_weight_
+        )
 
         unique_y = np.unique(y)
         if len(unique_y) == 1 and self.replace_classifiers:
             classifier = ConstantClassifier()
-        classifier.fit(X, y)
+        if not self.bert:
+            classifier.fit(X, y, sample_weight)
+        else:
+            classifier.fit(X, y)
         return classifier
 
     @staticmethod
-    def _remove_empty_leaves(separator, X, y):
+    def _remove_empty_leaves(separator, X, y, sample_weight):
         # Detect rows where leaves are not empty
         leaves = np.array([str(i).split(separator)[-1] for i in y])
         mask = leaves != ""
-        return X[mask], y[mask]
+        X = X[mask]
+        y = y[mask]
+        sample_weight = sample_weight[mask] if sample_weight is not None else None
+        return X, y, sample_weight
